Getting Started
============

.. include:: ./README.md
   :parser: myst_parser.sphinx_

.. toctree::
    :hidden:

    installation/index
    fundamentals/index
    first-steps/index
    advanced-fundamentals/index
